@@ -13,6 +13,7 @@
 import json
 import csv
 from io import StringIO
+import pandas as pd
 import cannerflow.workspace
 import cannerflow.constants
 import cannerflow.exceptions
@@ -85,6 +86,12 @@ class Client(object):
         return self._get_csv_wrapper(absolute_path, encoding).to_pandas(*args, **kwargs)
 
     def put_csv(self, absolute_path, data, encoding='utf-8', *args, **kwargs):
+        if isinstance(data, pd.DataFrame):
+            return self.put_pandas_csv(absolute_path, data, encoding='utf-8', *args, **kwargs)
+        else:
+            return self.put_csv_str(absolute_path, data, encoding='utf-8', *args, **kwargs)
+
+    def put_csv_str(self, absolute_path, data, encoding='utf-8', *args, **kwargs):
         str_io = StringIO()
         csv_writer = csv.writer(str_io, *args, **kwargs)
         csv_writer.writerows(data)
@@ -103,6 +110,12 @@ class Client(object):
         return self._get_json_wrapper(absolute_path, encoding).to_pandas(*args, **kwargs)
 
     def put_json(self, absolute_path, data, encoding='utf-8'):
+        if isinstance(data, pd.DataFrame):
+            return self.put_pandas_json(absolute_path, data, encoding='utf-8')
+        else:
+            return self.put_json_str(absolute_path, data, encoding='utf-8')
+
+    def put_json_str(self, absolute_path, data, encoding='utf-8'):
         data = json.dumps(data).encode(encoding)
         return self.put_binary(absolute_path=absolute_path, data=data)
 
